@@ -52,6 +52,7 @@ LEVELS = {'debug': logging.DEBUG,
 
 log = logging.getLogger(__name__)
 
+
 class Client(object):
     __version__ = '0.3.6'
     __protocol_version__ = '0.3'
@@ -73,7 +74,7 @@ class Client(object):
             errormator.slow_requests - record slow requests in application (needs to be enabled for slow datastore recording)
             errormator.logging - enable hooking to application loggers
             errormator.logging.level - minimum log level for log capture
-            errormator.datastores - enable query execution tracking for various datastore layers 
+            errormator.datastores - enable query execution tracking for various datastore layers
             errormator.slow_request_time - (float/int) time in seconds after request is considered being slow (default 30)
             errormator.slow_query_time - (float/int) time in seconds after datastore sql query is considered being slow (default 7)
             errormator.datastores.sqlalchemy = default true - tries to enable sqlalchemy query logging
@@ -115,11 +116,13 @@ class Client(object):
                 _tmp = __import__(parts[0], globals(), locals(), [parts[1], ], -1)
                 self.filter_callable = getattr(_tmp, parts[1])
             except ImportError as e:
-                self.filter_callable = None
+                self.filter_callable = self.data_filter
                 log.error('Could not import filter callable, using default, %s' % e)
+        else:
+            self.filter_callable = self.data_filter
 
         if self.config['buffer_flush_interval'] < 2:
-             self.config['buffer_flush_interval'] = 2
+            self.config['buffer_flush_interval'] = 2
         # register logging
         import errormator_client.logger
         if self.config['logging']:
@@ -168,7 +171,7 @@ class Client(object):
                 except KeyboardInterrupt as e:
                     raise KeyboardInterrupt()
                 except Exception as e:
-                    log.warning('report error %s' % e)
+                    log.warning('REPORTS: connection issue: %s' % e)
         send()
         # FIXME: reintroduce threads
 
@@ -188,7 +191,7 @@ class Client(object):
                 except KeyboardInterrupt as e:
                     raise KeyboardInterrupt()
                 except Exception as e:
-                    log.warning('slow report error %s' % e)
+                    log.warning('SLOW REPORTS: connection issue: %s' % e)
             if logs_to_send_items:
                 try:
                     self.remote_call(logs_to_send_items,
@@ -196,7 +199,7 @@ class Client(object):
                 except KeyboardInterrupt as e:
                     raise KeyboardInterrupt()
                 except Exception as e:
-                    log.warning('logs error %s' % e)
+                    log.warning('LOGS: connection issue: %s' % e)
         send()
         # FIXME: reintroduce threads
 
@@ -215,8 +218,6 @@ class Client(object):
         server_url = '%s%s?%s' % (self.config['server_url'], endpoint, GET_vars,)
         headers = {'content-type': 'application/json'}
         log.info('sending out %s entries to %s' % (len(data), endpoint,))
-
-
         try:
             req = urllib2.Request(server_url,
                                   json.dumps(data, cls=DateTimeEncoder),
@@ -238,22 +239,14 @@ class Client(object):
             log.error(message)
 
     def data_filter(self, structure, section=None):
-        if section == 'error_report':
+        if section in ['error_report','slow_report']:
             keys_to_check = (structure['report_details'][0]['request'].get('COOKIES'),
                               structure['report_details'][0]['request'].get('GET'),
                               structure['report_details'][0]['request'].get('POST')
                               )
-        elif section == 'slow_request':
-            keys_to_check = (structure['request'].get('COOKIES'),
-                              structure['request'].get('GET'),
-                              structure['request'].get('POST')
-                              )
-        else:
-            # do not filter for 404 by default
-            return structure
 
         for source in filter(None, keys_to_check):
-            for k, v in source.items():
+            for k in source.iterkeys():
                 if ('password' in k or 'passwd' in k or 'pwd' in k
                     or 'auth_tkt' in k or 'secret' in k):
                     source[k] = u'***'
@@ -263,8 +256,7 @@ class Client(object):
         report_data, errormator_info = create_report_structure(environ,
                         traceback, server=self.config['server_name'],
                         http_status=http_status, include_params=True)
-        report_data = self.filter_callable(report_data, 'error_report') if self.filter_callable else \
-                        self.data_filter(report_data, 'error_report')
+        report_data = self.filter_callable(report_data, 'error_report')
         url = report_data['report_details'][0]['url']
         with self.report_queue_lock:
             self.report_queue.append(report_data)
@@ -272,7 +264,7 @@ class Client(object):
                                           report_data.get('error_type'), url,))
         return True
 
-    def py_log(self, environ, records=None, uuid=None):
+    def py_log(self, environ, records=None, r_uuid=None):
         log_entries = []
         if not records:
             records = self.log_handler.get_records()
@@ -292,7 +284,7 @@ class Client(object):
                         'message':'%s' % (message.encode('utf8') if isinstance(message, unicode) else message,),
                         'server': self.config['server_name'],
                         'date':time_string,
-                        'request_id':uuid
+                        'request_id':r_uuid
                         })
             except (TypeError, UnicodeDecodeError, UnicodeEncodeError), e:
                 #handle some weird case where record.getMessage() fails
@@ -302,11 +294,10 @@ class Client(object):
         log.debug('add %s log entries to queue' % len(records))
         return {}
 
-    def py_slow_report(self, environ, start_time, end_time, records=[]):
+    def py_slow_report(self, environ, start_time, end_time, records=()):
         report_data, errormator_info = create_report_structure(environ,
                     server=self.config['server_name'], include_params=True)
-        report_data = self.filter_callable(report_data, 'error_report') if self.filter_callable else \
-                      self.data_filter(report_data, 'error_report')
+        report_data = self.filter_callable(report_data, 'slow_report')
         url = report_data['report_details'][0]['url']
         if not records:
             records = self.datastore_handler.get_records()
@@ -322,7 +313,6 @@ class Client(object):
         return True
 
 
-
 def make_errormator_middleware(app, global_config, **kw):
     config = global_config.copy()
     config.update(kw)
