@@ -1,10 +1,7 @@
 from webob import Request
 import datetime
 import json
-import socket
-import urllib
-import urllib2
-import threading
+
 
 def asbool(obj):
     if isinstance(obj, (str, unicode)):
@@ -18,6 +15,7 @@ def asbool(obj):
                 "String is not true/false: %r" % obj)
     return bool(obj)
 
+
 class DateTimeEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, datetime.date):
@@ -26,13 +24,17 @@ class DateTimeEncoder(json.JSONEncoder):
             return obj.isoformat()
         return json.JSONEncoder.default(self, obj)
 
+
 def process_environ(environ, traceback=None, include_params=False):
     # form friendly to json encode
     parsed_environ = {}
     errormator_info = {}
     req = Request(environ)
     for key, value in req.environ.items():
-        if key.startswith('errormator.') and key != 'errormator.client':
+        if key.startswith('errormator.') and key not in ('errormator.client',
+                                                    'errormator.force_send',
+                                                    'errormator.log',
+                                                    'errormator.report'):
             errormator_info[key[11:]] = unicode(value)
         else:
             if traceback or key.startswith('HTTP') or key in ('HTTP_USER_AGENT',):
@@ -47,21 +49,24 @@ def process_environ(environ, traceback=None, include_params=False):
     if include_params:
         parsed_environ['COOKIES'] = dict(req.cookies)
         parsed_environ['GET'] = dict([(k, req.GET.getall(k)) for k in req.GET])
-        parsed_environ['POST'] = dict([(k, req.POST.getall(k)) for k in req.POST])
-    # figure out real ip 
+        parsed_environ['POST'] = dict([(k, req.POST.getall(k))
+                                       for k in req.POST])
+    # figure out real ip
     if environ.get("HTTP_X_FORWARDED_FOR"):
         remote_addr = environ.get("HTTP_X_FORWARDED_FOR").split(',')[0].strip()
     else:
-        remote_addr = environ.get("HTTP_X_REAL_IP") or environ.get('REMOTE_ADDR')
+        remote_addr = (environ.get("HTTP_X_REAL_IP")
+                       or environ.get('REMOTE_ADDR'))
     parsed_environ['REMOTE_ADDR'] = remote_addr
     errormator_info['URL'] = req.url
     return parsed_environ, errormator_info
 
+
 def create_report_structure(environ, traceback=None, message=None,
             http_status=200, server='unknown server', include_params=False):
     (parsed_environ, errormator_info) = process_environ(environ, traceback,
                                                         include_params)
-    report_data = {'report_details': []}
+    report_data = {'client': 'Python', 'report_details': []}
     if traceback:
         exception_text = traceback.exception
         traceback_text = traceback.plaintext
@@ -69,7 +74,7 @@ def create_report_structure(environ, traceback=None, message=None,
         report_data['traceback'] = traceback_text
     report_data['http_status'] = 500 if traceback else http_status
     if http_status == 404:
-        report_data['error_type'] = '404 Not Found' 
+        report_data['error_type'] = '404 Not Found'
     report_data['priority'] = 5
     report_data['server'] = (server or
                 environ.get('SERVER_NAME', 'unknown server'))
@@ -80,6 +85,8 @@ def create_report_structure(environ, traceback=None, message=None,
     detail_entry['user_agent'] = parsed_environ.get('HTTP_USER_AGENT', u'')
     detail_entry['username'] = parsed_environ.get('REMOTE_USER', u'')
     detail_entry['url'] = errormator_info.pop('URL', 'unknown')
+    if 'request_id' in errormator_info:
+        detail_entry['request_id'] = errormator_info.pop('request_id', None)
     detail_entry['message'] = message or errormator_info.get('message', u'')
     #conserve bandwidth pop keys that we dont need in request details
     exclude_keys = ('HTTP_USER_AGENT', 'REMOTE_ADDR', 'HTTP_COOKIE',
